//[mahjong-utils](../../index.md)/[mahjongutils.models](index.md)/[countAsCodeArray](count-as-code-array.md)

# countAsCodeArray

[common]\
fun [Iterable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)&lt;[Tile](-tile/index.md)&gt;.[countAsCodeArray](count-as-code-array.md)(): [IntArray](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int-array/index.html)
